@@ -37,6 +37,7 @@ import org.apache.kyuubi.plugin.spark.authz.gen.KRangerPolicyResource._
 import org.apache.kyuubi.plugin.spark.authz.gen.RangerAccessType._
 import org.apache.kyuubi.plugin.spark.authz.gen.RangerClassConversions._
 import org.apache.kyuubi.util.AssertionUtils._
+import org.apache.kyuubi.util.GoldenFileUtils._
 
 /**
  * Generates the policy file to test/main/resources dir.
@@ -59,11 +60,9 @@ class PolicyJsonFileGenerator extends AnyFunSuite {
     .build()
 
   test("check ranger policy file") {
-    val pluginHome = getClass.getProtectionDomain.getCodeSource.getLocation.getPath
-      .split("target").head
     val policyFileName = "sparkSql_hive_jenkins.json"
-    val policyFilePath =
-      Paths.get(pluginHome, "src", "test", "resources", policyFileName)
+    val policyFilePath = Paths.get(
+      s"${getCurrentModuleHome(this)}/src/test/resources/$policyFileName")
     val generatedStr = mapper.writerWithDefaultPrettyPrinter()
       .writeValueAsString(servicePolicies)
 
@@ -108,6 +107,7 @@ class PolicyJsonFileGenerator extends AnyFunSuite {
       policyAccessForDefaultBobUse,
       policyAccessForDefaultBobSelect,
       policyAccessForPermViewAccessOnly,
+      policyAccessForTable2AccessOnly,
       // row filter
       policyFilterForSrcTableKeyLessThan20,
       policyFilterForPermViewKeyLessThan20,
@@ -345,4 +345,16 @@ class PolicyJsonFileGenerator extends AnyFunSuite {
         users = List(permViewOnlyUser),
         accesses = allowTypes(select),
         delegateAdmin = true)))
+
+  private val policyAccessForTable2AccessOnly = KRangerPolicy(
+    name = "someone_access_table2",
+    resources = Map(
+      databaseRes(defaultDb),
+      tableRes("table2"),
+      allColumnRes),
+    policyItems = List(
+      KRangerPolicyItem(
+        users = List(table2OnlyUser),
+        accesses = allowTypes(select),
+        delegateAdmin = true)))
 }
