@@ -28,16 +28,16 @@ import org.apache.flink.configuration.Configuration
 import org.apache.flink.table.gateway.service.context.SessionContext
 import org.apache.flink.table.gateway.service.operation.OperationExecutor
 import org.apache.flink.types.Row
-import org.apache.hive.service.rpc.thrift.{TFetchResultsResp, TGetResultSetMetadataResp, TTableSchema}
 
 import org.apache.kyuubi.{KyuubiSQLException, Utils}
 import org.apache.kyuubi.engine.flink.result.ResultSet
-import org.apache.kyuubi.engine.flink.schema.RowSet
+import org.apache.kyuubi.engine.flink.schema.{FlinkTRowSetGenerator, RowSet}
 import org.apache.kyuubi.engine.flink.session.FlinkSessionImpl
 import org.apache.kyuubi.operation.{AbstractOperation, OperationState}
 import org.apache.kyuubi.operation.FetchOrientation.{FETCH_FIRST, FETCH_NEXT, FETCH_PRIOR, FetchOrientation}
 import org.apache.kyuubi.operation.log.OperationLog
 import org.apache.kyuubi.session.Session
+import org.apache.kyuubi.shaded.hive.service.rpc.thrift.{TFetchResultsResp, TGetResultSetMetadataResp, TTableSchema}
 
 abstract class FlinkOperation(session: Session) extends AbstractOperation(session) {
 
@@ -133,10 +133,9 @@ abstract class FlinkOperation(session: Session) extends AbstractOperation(sessio
       case Some(tz) => ZoneId.of(tz)
       case None => ZoneId.systemDefault()
     }
-    val resultRowSet = RowSet.resultSetToTRowSet(
+    val resultRowSet = new FlinkTRowSetGenerator(zoneId).toTRowSet(
       batch.toList,
       resultSet,
-      zoneId,
       getProtocolVersion)
     val resp = new TFetchResultsResp(OK_STATUS)
     resp.setResults(resultRowSet)
